@@ -15,19 +15,19 @@ REVISION:      2001.10.10 first created.
 #include <QtCore/QFileInfo>
 #include <QtCore/QStringList>
 #include <QtCore/QString>
-#include <QtGui/QMessageBox>
+#include <QMessageBox>
 #include <QtDebug>
 
 namespace QTerm
 {
 
-const QString Config::m_version = "1.8";
+const QString Config::m_version = "1.11";
 
 Config::Config(const QString & szFileName)
 {
     if (QFile::exists(szFileName)) {
         m_settings = new QSettings(szFileName, QSettings::IniFormat);
-        checkVersion();
+        checkVersion(szFileName);
     } else {
         m_settings = new QSettings(szFileName, QSettings::IniFormat);
         m_settings->setValue("version", m_version);
@@ -84,17 +84,17 @@ void Config::addToolBars()
     m_settings->beginGroup("ToolBars");
     QStringList listActions;
     listActions << "actionQuickConnect";
-    m_settings->setValue("mainToolBar", listActions);
+    m_settings->setValue("terminalToolBar", listActions);
     listActions.clear();
     listActions << "actionDisconnect" << "Separator" << "actionCopy" << "actionPaste" << "actionRect" << "actionColorCopy" << "Separator" << "actionFont" << "actionColor" << "actionRefresh" << "Separator" << "actionCurrentSession" << "Separator" << "actionCopyArticle" << "actionAntiIdle" << "actionAutoReply" << "actionViewMessage" << "actionMouse" << "actionBeep" << "actionReconnect";
-    m_settings->setValue("bbsOperationsToolBar",listActions);
-    m_settings->setValue("mainToolBarShown", true);
-    m_settings->setValue("customKeyToolBarShown", true);
-    m_settings->setValue("bbsOperationsToolBarShown",true);
+    m_settings->setValue("mainToolBar",listActions);
+    m_settings->setValue("terminalToolBarShown", true);
+    m_settings->setValue("keyToolBarShown", true);
+    m_settings->setValue("mainToolBarShown",true);
     m_settings->endGroup();
 }
 
-bool Config::checkVersion()
+bool Config::checkVersion(const QString & szFileName)
 {
     QString version = m_settings->value("version").toString();
 
@@ -102,7 +102,16 @@ bool Config::checkVersion()
         QMessageBox::warning(0, "Old Version","The version of your config file is outdated.\n" "It will be automatically updated, but you should check for errors");
         upgrade();
     } else if (m_version != version) {
-        QMessageBox::warning(0, "Version Mismath","The version of your config file is not match the current QTerm version.\n" "It will be automatically updated, but you should check for errors");
+        QString bakFile = szFileName+".bak";
+        QMessageBox::warning(0, "Version Mismath","The version of your config file is not match the current QTerm version.\n" "The old config file will be backed up as: "+bakFile);
+
+        if (QFile::exists(bakFile))
+        {
+            QFile::remove(bakFile);
+        }
+
+        QFile::copy(szFileName, bakFile);
+
         m_settings->setValue("version", m_version);
         upgrade();
         return false;
