@@ -12,7 +12,7 @@ class soundConf : public QDialog
 	Q_OBJECT
 
 public:
-	soundConf( QWidget* parent = 0, Qt::WindowFlags fl = 0 );
+	soundConf( QWidget* parent = 0, Qt::WindowFlags fl = Qt::Widget );
 	~soundConf();
 	void loadSetting();
 	void saveSetting();
